
CHANGES
=======

0.4 (2014-03-30)
----------------

- Implement dict-like interface (e.g., sketch['key'])
- Add filter() method
- Add values() method for dumping all values

0.3 (2014-03-14)
----------------

- Key length is automatically determined when it is not given
- Remove filter function
- Slightly decreasing amount of memory usage

0.2 (2013-10-12)
----------------

Simplify the step of creating new sketch.

0.1 (2013-10-11)
----------------

Initial release.

